@@ -34,7 +34,13 @@ from werkzeug.exceptions import (
     NotAcceptable,
     InternalServerError,
 )
-from werkzeug.wrappers import BaseResponse
+
+from werkzeug import __version__ as werkzeug_version
+
+if werkzeug_version.split('.')[0] >= '2':
+    from werkzeug.wrappers import Response as BaseResponse
+else:
+    from werkzeug.wrappers import BaseResponse
 
 from . import apidoc
 from .mask import ParseError, MaskError
@@ -673,8 +679,6 @@ class Api(object):
         :param Exception e: the raised Exception object
 
         """
-        got_request_exception.send(current_app._get_current_object(), exception=e)
-
         # When propagate_exceptions is set, do not return the exception to the
         # client if a handler is configured for the exception.
         if (
@@ -704,6 +708,10 @@ class Api(object):
                 )
                 break
         else:
+            # Flask docs say: "This signal is not sent for HTTPException or other exceptions that have error handlers
+            # registered, unless the exception was raised from an error handler."
+            got_request_exception.send(current_app._get_current_object(), exception=e)
+
             if isinstance(e, HTTPException):
                 code = HTTPStatus(e.code)
                 if include_message_in_response:
