@@ -481,6 +481,8 @@ class Float(NumberMixin, Raw):
 
     def format(self, value):
         try:
+            if value is None:
+                return self.default
             return float(value)
         except (ValueError, TypeError) as ve:
             raise MarshallingError(ve)
@@ -862,7 +864,12 @@ class Wildcard(Raw):
                     # we are using pop() so that we don't
                     # loop over the whole object every time dropping the
                     # complexity to O(n)
-                    (objkey, val) = self._flat.pop()
+                    if ordered:
+                        # Get first element if respecting order
+                        (objkey, val) = self._flat.pop(0)
+                    else:
+                        # Previous default retained
+                        (objkey, val) = self._flat.pop()
                     if (
                         objkey not in self._cache
                         and objkey not in self.exclude
